@@ -1,22 +1,22 @@
-module Thin  
+module Thin
   # Raised when a feature is not supported on the
   # current platform.
   class PlatformNotSupported < RuntimeError; end
   
   module VERSION #:nodoc:
     MAJOR    = 1
-    MINOR    = 6
-    TINY     = 3
+    MINOR    = 8
+    TINY     = 0
     
     STRING   = [MAJOR, MINOR, TINY].join('.')
     
-    CODENAME = "Protein Powder".freeze
+    CODENAME = "Possessed Pickle".freeze
     
     RACK     = [1, 0].freeze # Rack protocol version
   end
   
   NAME    = 'thin'.freeze
-  SERVER  = "#{NAME} #{VERSION::STRING} codename #{VERSION::CODENAME}".freeze  
+  SERVER  = "#{NAME} #{VERSION::STRING} codename #{VERSION::CODENAME}".freeze
   
   def self.win?
     RUBY_PLATFORM =~ /mswin|mingw/
